
package com.redxun.certificate.core.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.redxun.certificate.core.entity.Certificate;
import com.redxun.certificate.core.mapper.CertificateMapper;
import com.redxun.certificate.core.service.CertificateServiceImpl;
import com.redxun.common.annotation.ClassDefine;
import com.redxun.common.base.db.BaseService;
import com.redxun.common.base.entity.JsonPageResult;
import com.redxun.common.base.entity.JsonResult;
import com.redxun.common.base.entity.QueryData;
import com.redxun.common.base.search.QueryFilter;
import com.redxun.common.base.search.QueryFilterBuilder;
import com.redxun.common.utils.ExceptionUtil;
import com.redxun.web.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@Slf4j
@RestController
@RequestMapping("/certificate/core/certificate")
@Api(tags = "证书")
@ClassDefine(title = "证书", alias = "CertificateController", path = "/certificate/core/certificate", packages = "core", packageName = "子系统名称")
public class CertificateController extends BaseController<Certificate> {

    @Resource
    CertificateServiceImpl certificateService;
//    @Autowired
//    CertificateMapper certificateMapper;

    @Override
    public BaseService getBaseService() {
        return certificateService;
    }

    @Override
    public String getComment() {
        return "证书";
    }

    @ApiOperation(value = "查看所有证书")
    @ApiImplicitParam(name = "queryData", value = "查询条件")
    @PostMapping("/selectCertificateAll")
    public JsonPageResult selectCertificateAll(@RequestBody QueryData queryData) {
        JsonPageResult jsonResult = JsonPageResult.getSuccess("返回数据成功!");
        try {
            QueryFilter filter = QueryFilterBuilder.createQueryFilter(queryData);
            IPage page = certificateService.selectCertificateAll(filter);
            this.handlePage(page);
            jsonResult.setPageData(page);
        } catch (Exception e) {
            jsonResult.setSuccess(false);
            this.logger.error(ExceptionUtil.getExceptionMessage(e));
            jsonResult.setMessage(ExceptionUtil.getExceptionMessage(e));
        }
        return jsonResult;
    }


    @ApiOperation(value = "查看用户拥有的证书")
    @ApiImplicitParam(name = "queryData", value = "查询条件")
    @PostMapping("/selectCertificateForUser")
    public JsonPageResult selectCertificateForUser(@RequestBody QueryData queryData) {
        JsonPageResult jsonResult = JsonPageResult.getSuccess("返回数据成功!");
        try {
            QueryFilter filter = QueryFilterBuilder.createQueryFilter(queryData);
            IPage page = certificateService.selectUserCertificate(filter);
            this.handlePage(page);
            jsonResult.setPageData(page);
        } catch (Exception e) {
            jsonResult.setSuccess(false);
            this.logger.error(ExceptionUtil.getExceptionMessage(e));
            jsonResult.setMessage(ExceptionUtil.getExceptionMessage(e));
        }
        return jsonResult;
    }

    @ApiOperation(value = "带有效期的证书列表查询")
    @ApiImplicitParam(name = "queryData", value = "查询条件")
    @PostMapping("/selectValidCertificate")
    public JsonPageResult selectValidCertificate(@RequestBody QueryData queryData) {
        JsonPageResult jsonResult = JsonPageResult.getSuccess("返回数据成功!");
        try {
            QueryFilter filter = QueryFilterBuilder.createQueryFilter(queryData);
            IPage page = certificateService.selectValidCertificate(filter);
            this.handlePage(page);
            jsonResult.setPageData(page);
        } catch (Exception e) {
            jsonResult.setSuccess(false);
            this.logger.error(ExceptionUtil.getExceptionMessage(e));
            jsonResult.setMessage(ExceptionUtil.getExceptionMessage(e));
        }
        return jsonResult;
    }
}

