
/**
 * <pre>
 *
 * 描述：证书实体类定义
 * 表:certificate
 * 作者：phy
 * 邮箱: penghongyan@redxun.cn
 * 日期:2022-06-29 14:46:07
 * 版权：广州红迅软件
 * </pre>
 */
package com.redxun.certificate.core.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.redxun.common.base.entity.BaseExtEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;
import org.apache.ibatis.type.JdbcType;


@Setter
@Getter
@Accessors(chain = true)
@TableName(value = "CERTIFICATE")
@ApiModel(description = "CERTIFICATE")
public class Certificate extends BaseExtEntity<String> {

    @JsonCreator
    public Certificate() {
    }

    //ID
    @TableId(value = "ID_", type = IdType.INPUT)
    @ApiModelProperty(value = "ID")
    private String id;

    //外键
    @TableField(value = "REF_ID_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "外键")
    private String refId;

    //证书编号
    @TableField(value = "CERTIFICATE_NO_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书编号")
    private String certificateNo;

    //证书名称
    @TableField(value = "CERTIFICATE_NAME_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书名称")
    private String certificateName;

    //所属分类ID(来自数据字典)
    @TableField(value = "CLASSIFY_ID_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "所属分类ID")
    private String classifyId;

    //所属分类ID(来自数据字典)
    @TableField(value = "CLASSIFY_NAME_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "所属分类Name")
    private String classifyName;

    //证书图片
    @TableField(value = "CERTIFICATE_PICTURE_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书图片")
    private String certificatePicture;

    //证书附件
    @TableField(value = "CERTIFICATE_ATTACHMENT_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书附件")
    private String certificateAttachment;

    //证书简介
    @TableField(value = "CERTIFICATE_INTRODUCTION_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书简介")
    private String certificateIntroduction;

    //颁发次数
    @TableField(value = "ISSUANCE_TIMES_", jdbcType = JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "颁发次数")
    private Integer issuanceTimes;

    //有效期
    @TableField(value = "VALID_DATE_", jdbcType = JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "有效期")
    private Integer validDate;

    //是否启用  0-禁用 1-启用
    @TableField(value = "ENABLE_", jdbcType = JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "是否启用  0-禁用 1-启用")
    private Integer enable;

    //证书生效日期
    @org.springframework.format.annotation.DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @com.alibaba.fastjson.annotation.JSONField(format = "yyyy-MM-dd HH:mm:ss")
    @com.fasterxml.jackson.annotation.JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value = "CERTIFICATE_EFFECTIVE_DATE_", jdbcType = JdbcType.DATE, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书生效日期")
    private java.util.Date certificateEffectiveDate;

    //状态   草稿-2、已发布-1、禁用-0
    @TableField(value = "STATUS_",jdbcType=JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "状态")
    private Integer status;

    //制作人ID
    @TableField(value = "PRODUCER_ID_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "制作人ID")
    private String producerId;

    //制作人NAME
    @TableField(value = "PRODUCER_NAME_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "制作人NAME")
    private String producerName;

    //流程实例ID
    @TableField(value = "INST_ID_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "流程实例ID")
    private String instId;

    //流程状态
    @TableField(value = "INST_STATUS_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "流程状态")
    private String instStatus;

    //应用id
    @TableField(value = "APP_ID_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "应用id")
    private String appId;

    //版本号
    @TableField(value = "VERSION_", jdbcType = JdbcType.VARCHAR, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "版本号")
    private String version;

    //版本步长
    @TableField(value = "VER_STEP_", jdbcType = JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "版本步长")
    private Integer verStep;

    //证书类型(0-上传证书，1-证书模板)
    @TableField(value = "CERTIFICATE_TYPE_", jdbcType = JdbcType.NUMERIC, updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "证书类型")
    private Integer certificateType;


    //证书是否过期
    @TableField(exist = false)
    private String certificateStatus;

    @Override
    public String getPkId() {
        return id;
    }

    @Override
    public void setPkId(String pkId) {
        this.id = pkId;
    }

    /**
     * 生成子表属性的Array List
     */
}